@@ -2,7 +2,7 @@ from enum import Enum
 
 
 class Activity(Enum):
-    custom = 0  # you can insert custom ID here
+    custom = 0  # you can insert activity_id parameter while setting this as activities, honestly very useless since nextcord already have target_application_id, but heck yeah
     poker = 1  # boost-locked
     betrayal = 2
     fishington = 3
@@ -17,3 +17,4 @@ class Activity(Enum):
     spellcast = 12  # boost-locked
     letter_league = 13  # boost-locked
     awkword = 14  # boost-locked
+    blazing = 15
\ No newline at end of file
